@@ -1,21 +1,7 @@
 /*
- * Copyright 2016 Aleix Pol Gonzalez <aleixpol@kde.org>
+ * SPDX-FileCopyrightText: 2016 Aleix Pol Gonzalez <aleixpol@kde.org>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #include <QApplication>
@@ -70,7 +56,7 @@ int main(int argc, char** argv)
     QMenu* menu = new QMenu;
 
     DaemonDbusInterface iface;
-    auto refreshMenu = [&iface, &model, &menu]() {
+    auto refreshMenu = [&iface, &model, &menu, &helper]() {
         menu->clear();
         auto configure = menu->addAction(QIcon::fromTheme(QStringLiteral("configure")), i18n("Configure..."));
         QObject::connect(configure, &QAction::triggered, configure, [](){
@@ -97,9 +83,9 @@ int main(int argc, char** argv)
                 pairMenu->addAction(i18n("Reject"), dev, &DeviceDbusInterface::rejectPairing);
             }
         }
-
-#if (defined Q_OS_MAC || defined Q_OS_WIN)
         // Add quit menu
+#if defined Q_OS_MAC
+
         menu->addAction(i18n("Quit"), [](){
             auto message = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kdeconnect.daemon"),
                                                         QStringLiteral("/MainApplication"),
@@ -112,6 +98,14 @@ int main(int argc, char** argv)
                                                         QStringLiteral("quit"));
             DBusHelper::sessionBus().call(message, QDBus::NoBlock); // Close our indicator
         });
+#elif defined Q_OS_WIN
+
+        menu->addAction(i18n("Quit"), [&helper](){
+            const QUrl indicatorUrl = QUrl::fromLocalFile(qApp->applicationDirPath());
+            helper.terminateProcess(processes::dbus_daemon, indicatorUrl);
+            helper.terminateProcess(processes::kdeconnect_daemon, indicatorUrl);
+            qApp->quit();
+        });
 #endif
     };
 
